@@ -4,7 +4,7 @@ source(testthat::test_path("test_helpers.R"))
 
 # ------------------------------------------------------------------------------
 
-data("credit_data")
+data("credit_data", package = "modeldata")
 
 set.seed(342)
 in_training <- sample(1:nrow(credit_data), 2000)
@@ -71,20 +71,24 @@ test_that("Laplace works", {
 # dictionary
 
 test_that("dictionary returns a proper tibble", {
-  expect_equal(dictionary(df, y) %>% class, c("tbl_df", "tbl", "data.frame"))
-  expect_equal(dictionary(df, y) %>% dim, c(6, 8))
-  expect_identical(dictionary(df, y) %>% names, c("variable", "predictor", "n_tot", "n_A", "n_B", "p_A", "p_B", "woe"))
+  expect_equal(dictionary(df, "y") %>% class, c("tbl_df", "tbl", "data.frame"))
+  expect_equal(dictionary(df, "y") %>% dim, c(6, 9))
+  expect_identical(dictionary(df, "y") %>% names, 
+                   c("variable", "predictor", "n_tot", "n_A", "n_B", 
+                     "p_A", "p_B", "woe", "outcome"))
 })
 
 test_that("dictionary accepts numeric, logical and character predictor variables", {
-  expect_equal(dim(dictionary(mutate(df,
-                                         x3 = rep(c(TRUE, FALSE), 10),
-                                         x4 = rep(c(20, 30), 10)), y)), c(10, 8))
+  tmp <- mutate(df, x3 = rep(c(TRUE, FALSE), 10), x4 = rep(c(20, 30), 10))
+  expect_equal(
+    dim(dictionary(tmp, "y")), 
+    c(10, 9)
+  )
 })
 
 test_that("dictionary returns no messages nor warnings nor errors", {
-  expect_silent(dictionary(df, y, x1))
-  expect_silent(dictionary(df %>% mutate(x3 = rep(c(TRUE, FALSE), 10)), y, x3))
+  expect_silent(dictionary(df, "y", x1))
+  expect_silent(dictionary(df %>% mutate(x3 = rep(c(TRUE, FALSE), 10)), "y", x3))
 })
 
 
@@ -92,9 +96,9 @@ test_that("dictionary returns no messages nor warnings nor errors", {
 # add_woe
 
 test_that("add_woe returns a proper tibble", {
-  expect_equal(add_woe(df, y) %>% class, c("tbl_df", "tbl", "data.frame"))
-  expect_equal(add_woe(df, y) %>% dim, c(20, 5))
-  expect_identical(add_woe(df, y) %>% names, c("x1", "x2", "y", "woe_x1", "woe_x2"))
+  expect_equal(add_woe(df, "y") %>% class(), c("tbl_df", "tbl", "data.frame"))
+  expect_equal(add_woe(df, "y") %>% dim, c(20, 5))
+  expect_identical(add_woe(df, "y") %>% names, c("x1", "x2", "y", "woe_x1", "woe_x2"))
 })
 
 test_that("add_woe accepts only outcome with 2 distinct categories", {
@@ -102,30 +106,31 @@ test_that("add_woe accepts only outcome with 2 distinct categories", {
 })
 
 test_that("add_woe ruturns no messages nor warnings nor errors", {
-  expect_silent(add_woe(df, y, x1))
-  expect_silent(add_woe(df %>% mutate(x3 = rep(c(TRUE, FALSE), 10)), y, x3))
+  expect_silent(add_woe(df, "y", x1))
+  expect_silent(add_woe(df %>% mutate(x3 = rep(c(TRUE, FALSE), 10)), "y", x3))
 })
 
 test_that("add_woe accepts numeric, logical and character predictor variables", {
   expect_equal(add_woe(df %>% mutate(x3 = rep(c(TRUE, FALSE), 10),
-                                     x4 = rep(c(20, 30), 10)), y) %>% dim, c(20, 9))
+                                     x4 = rep(c(20, 30), 10)), "y") %>% dim, c(20, 9))
 })
 
 test_that("add_woe returns woe only for those variables that exists in both data and dictionary", {
-  expect_equal(names(add_woe(df, y, x2, dictionary = dictionary(df, y, x1))), c("x1", "x2", "y"))
-  expect_equal(names(add_woe(df, y, x1, dictionary = dictionary(df, y, x1))), c("x1", "x2", "y", "woe_x1"))
-  expect_equal(names(add_woe(df, y, dictionary = dictionary(df, y, x1))), c("x1", "x2", "y", "woe_x1"))
-  expect_equal(names(add_woe(df, y, x1, x2, dictionary = dictionary(df, y, x1))), c("x1", "x2", "y", "woe_x1"))
+  expect_equal(names(add_woe(df, "y", x2, dictionary = dictionary(df, "y", x1))), c("x1", "x2", "y"))
+  expect_equal(names(add_woe(df, "y", x1, dictionary = dictionary(df, "y", x1))), c("x1", "x2", "y", "woe_x1"))
+  expect_equal(names(add_woe(df, "y", dictionary = dictionary(df, "y", x1))), c("x1", "x2", "y", "woe_x1"))
+  expect_equal(names(add_woe(df, "y", x1, x2, dictionary = dictionary(df, "y", x1))), c("x1", "x2", "y", "woe_x1"))
 })
 
 test_that("add_woe do not accept dictionary with unexpected layout", {
-  expect_error(add_woe(df, outcome = y, x1, dictionary = iris))
-  expect_error(add_woe(df, outcome = y, x1, dictionary = iris %>% mutate(variable = 1)))
+  expect_error(add_woe(df, outcome = "y", x1, dictionary = iris))
+  expect_error(add_woe(df, outcome = "y", x1, dictionary = iris %>% mutate(variable = 1)))
 })
 
 test_that("add_woe warns user if the variable has too many levels", {
-  expect_warning(credit_data %>% add_woe(Status, Expenses))
+  expect_warning(credit_data %>% add_woe("Status", Expenses))
 })
+
 #------------------------------------
 # step_woe
 
@@ -133,17 +138,17 @@ test_that("step_woe", {
 
   rec <-
     recipe(Status ~ ., data = credit_tr) %>%
-    step_woe(Job, Home, outcome = Status)
+    step_woe(Job, Home, outcome = vars(Status))
 
   woe_models <- prep(rec, training = credit_tr)
 
-  woe_dict <- credit_tr %>% dictionary(Status, Job, Home)
+  woe_dict <- credit_tr %>% dictionary("Status", Job, Home)
   expect_equal(woe_dict, woe_models$steps[[1]]$dictionary)
 
   bake_woe_output <- bake(woe_models, new_data = credit_te)
   add_woe_output <-
     credit_te %>%
-    add_woe(Status, Job, Home, dictionary = woe_dict)  %>%
+    add_woe("Status", Job, Home, dictionary = woe_dict)  %>%
     dplyr::select(one_of(names(bake_woe_output)))
 
   #
@@ -151,27 +156,27 @@ test_that("step_woe", {
 
   tidy_output <- tidy(woe_models, number = 1)
   woe_dict_output <- 
-    dictionary(credit_tr, Job, Home, outcome = Status) %>% 
+    dictionary(credit_tr, Job, Home, outcome = "Status") %>% 
     dplyr::rename(terms = variable, value = predictor)
 
   #
   expect_equal(tidy_output %>% dplyr::select(-id), woe_dict_output)
 
   rec_all_nominal <- recipe(Status ~ ., data = credit_tr) %>%
-    step_woe(all_nominal(), outcome = Status)
+    step_woe(all_nominal(), outcome = vars(Status))
 
   #
   expect_output(prep(rec_all_nominal, training = credit_tr, verbose = TRUE))
 
 
   rec_all_numeric <- recipe(Status ~ ., data = credit_tr) %>%
-    step_woe(all_predictors(), outcome = Status)
+    step_woe(all_predictors(), outcome = vars(Status))
 
   #
   expect_error(prep(rec_all_numeric, training = credit_tr))
 
   rec_discretize <- recipe(Status ~ ., data = credit_tr) %>% step_discretize(Price)
-  rec_discretize_woe <- rec_discretize %>%step_woe(Price, outcome = Status)
+  rec_discretize_woe <- rec_discretize %>%step_woe(Price, outcome = vars(Status))
 
   prep_discretize <- prep(rec_discretize, training = credit_tr)
   prep_discretize_woe <- prep(rec_discretize_woe, training = credit_tr)
@@ -185,7 +190,7 @@ test_that("step_woe", {
 
 test_that("printing", {
   woe_extract <- recipe(Status ~ ., data = credit_tr) %>%
-    step_woe(Job, Home, outcome = Status)
+    step_woe(Job, Home, outcome = vars(Status))
   expect_output(print(woe_extract))
   expect_output(prep(woe_extract, training = credit_tr, verbose = TRUE))
 })
@@ -197,7 +202,7 @@ test_that("2-level factors", {
 
   expect_error(
     recipe(Species ~ ., data = iris3) %>%
-    step_woe(group, outcome = Species) %>%
+    step_woe(group, outcome = vars(Species)) %>%
     prep()
   )
 })
